#!/bin/bash
# COPYRIGHT (c) 2018 ORACLE A-TEAM
# THIS SAMPLE CODE IS PROVIDED FOR EDUCATIONAL PURPOSES OR
# TO ASSIST YOUR DEVELOPMENT OR ADMINISTRATION EFFORTS AND
# PROVIDED "AS IS" AND IS NOT SUPPORTED BY ORACLE CORPORATION.

if [[ $EUID -ne 0 ]]; then
   echo "This script must be run as root" 
   exit 1
fi

# Function to determine OS Distro
check_distro2() {
   if [[ -e /etc/redhat-release ]]
   then
      DISTRO=$(cat /etc/redhat-release | awk -F. '{print $1}')
   elif [[ -e /usr/bin/lsb_release ]]
   then
      DISTRO=$(lsb_release -d | awk -F ':' '{print $2}' | awk -F. '{print $1}')
   elif [[ -e /etc/issue ]]
   then
      DISTRO=$(cat /etc/issue | awk -F. '{print $1}')
   else
      DISTRO=$(cat /proc/version | awk -F. '{print $1}')
   fi

   if [ "$DISTRO" = "Red Hat Enterprise Linux Server release 6" ]
   then
      EPEL_RELEASE="https://dl.fedoraproject.org/pub/epel/epel-release-latest-6.noarch.rpm"
   elif [ "$DISTRO" = "Red Hat Enterprise Linux Server release 7" ]
   then
      EPEL_RELEASE="https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm"
   fi
}

# Start install of Epel, NodeJS, and Newman
echo -e "Installing Epel, NodeJS, and Newman on $DISTRO"
echo -e "IMPORTANT:  "
echo -e "When NodeJS is being setup, it will warn you about a 20 second wait."
echo -e "Please be patient and let it finish, DO NOT ABORT...wait for it to finish."
echo -e "\n"
read -n 1 -s -r -p "Press any key to continue"

# 1st - Install Epel
echo -e "Installing Epel..."
cd /tmp
yum install -y repolist
check_distro2
wget $EPEL_RELEASE
yum install -y epel-release-latest-*.noarch.rpm

# 2nd - Install NodeJS (Note: curl command will evaluate system and take 30 seconds...be patient)
echo -e "Installing NodeJS..."
curl -sL https://rpm.nodesource.com/setup | sudo bash -
yum install -y npm --enablerepo=epel
npm config set strict-ssl false
npm install n -g
n latest

# 3rd - Install Newman
echo -e "Installing Newman..."
npm install -g newman

# 4th - Check the versions
echo -e "Checking versions to indicate success..."
# NodeJS
echo -e "Checking NodeJS version - should return v10.9.0"
node -v

# NPM
echo -e "Checking NPM version - hould return 1.3.6 (RHEL6/OEL6) or 3.10.20 (RHEL7/OEL7)"
npm -v

# Newman
echo -e "Checking Newman version - should return 4.1.0"
newman -v

# 5th - Install Reporters
echo -e "Installing Newman Reporters..."
npm install -g newman-reporter-teamcity
